@@ -21,7 +21,7 @@ pompCBuilder <- function (name = NULL, dir = NULL,
     if (.Platform$OS.type=="unix") {
         pompheader <- "pomp.h"
     } else {
-        pompheader <- system.file("include/pomp.h",package="pomp")
+        pompheader <- system.file("include/pomp.h",package="pomp") # nocov
     }
 
     csrc <- ""
@@ -29,9 +29,9 @@ pompCBuilder <- function (name = NULL, dir = NULL,
 
     cat(file=out,render(header$file,pompheader=pompheader,id=id))
 
-    for (f in utility.fns) {
-        cat(file=out,f)
-    }
+##    for (f in utility.fns) {
+##        cat(file=out,f)
+##    }
 
     cat(file=out,globals,footer$globals)
 
@@ -171,8 +171,7 @@ pompCBuilder <- function (name = NULL, dir = NULL,
     tryCatch(
         pompCompile(fname=name,direc=pompSrcDir(dir),src=csrc,verbose=verbose),
         error = function (e) {
-            stop("in ",sQuote("pompCBuilder"),": compilation error: ",
-                 conditionMessage(e),call.=FALSE)
+            stop("in ",sQuote("pompCBuilder"),": compilation error: ",conditionMessage(e),call.=FALSE)
         }
     )
     
@@ -185,11 +184,13 @@ pompSrcDir <- function (dir) {
         dir <- file.path(tempdir(),pid)
     }
     tryCatch(
-        dir.create(dir,recursive=TRUE,showWarnings=FALSE,mode="0700"),
-        error = function (e) {
-            stop("cannot create cache directory ",sQuote(dir),": ",
-                 conditionMessage(e),call.=FALSE)
-        }
+    {
+        dir.create(dir,recursive=TRUE,showWarnings=FALSE,mode="0700")
+        stopifnot(dir.exists(dir))
+    },
+    error = function (e) {
+        stop("cannot create cache directory ",sQuote(dir),call.=FALSE)
+    }
     )
     dir
 }
@@ -197,9 +198,8 @@ pompSrcDir <- function (dir) {
 pompCompile <- function (fname, direc, src, verbose) {
 
     stem <- file.path(direc,fname)
-    if (.Platform$OS.type=="windows") {
-        stem <- gsub("\\","/",stem,fixed=TRUE)
-    }
+    if (.Platform$OS.type=="windows")
+        stem <- gsub("\\","/",stem,fixed=TRUE) # nocov
 
     modelfile <- paste0(stem,".c")
 
@@ -231,10 +231,6 @@ callable.decl <- function (code) {
     do.call(paste0,decl[fns])
 }
 
-missing.fun <- function (name) {
-    paste0("  error(\"'",name,"' not defined\");")
-}
-
 randomName <- function (size = 4, stem = "") {
     paste0(stem,
            " Time: ",format(Sys.time(),"%Y-%m-%d %H:%M:%OS3 %z"),
@@ -261,8 +257,7 @@ render <- function (template, ...) {
     if (length(vars)==0) return(template)
     n <- sapply(vars,length)
     if (!all((n==max(n))|(n==1)))
-        stop("in ",sQuote("render"),
-             "incommensurate lengths of replacements",call.=FALSE)
+        stop("in ",sQuote("render"),"incommensurate lengths of replacements",call.=FALSE)
     short <- which(n==1)
     n <- max(n)
     for (i in short) vars[[i]] <- rep(vars[[i]],n)
@@ -349,4 +344,4 @@ void __pomp_load_stack_decr (int *val) {
   *val = --__pomp_load_stack;
 }\n"
 
-utility.fns <- list()
+## utility.fns <- list()
