@@ -1,6 +1,8 @@
 ## simulate the process model
 
 rprocess.internal <- function (object, xstart, times, params, offset = 0, .getnativesymbolinfo = TRUE, ...) {
+    storage.mode(xstart) <- "double"
+    storage.mode(params) <- "double"
     pompLoad(object)
     rv <- .Call(do_rprocess,object,xstart,times,params,offset,.getnativesymbolinfo)
     pompUnload(object)
