@@ -15,7 +15,7 @@ SEXP apply_probe_data (SEXP object, SEXP probes) {
   for (i = 0; i < nprobe; i++) {
     SET_ELEMENT(vals,i,eval(lang2(VECTOR_ELT(probes,i),data),CLOENV(VECTOR_ELT(probes,i))));
     if (!IS_NUMERIC(VECTOR_ELT(vals,i))) {
-      errorcall(R_NilValue,"probe %ld returns a non-numeric result",i);
+      errorcall(R_NilValue,"probe %ld returns a non-numeric result",i+1);
     }
   }
 
@@ -98,14 +98,14 @@ SEXP apply_probe_sim (SEXP object, SEXP nsim, SEXP params, SEXP seed, SEXP probe
       // evaluate the probe on the simulated data
       PROTECT(val = eval(lang2(VECTOR_ELT(probes,p),x),CLOENV(VECTOR_ELT(probes,p))));
       if (!IS_NUMERIC(val)) {
-	errorcall(R_NilValue,"probe %ld returns a non-numeric result",p);
+	errorcall(R_NilValue,"probe %ld returns a non-numeric result",p+1);
       }
 
       len = LENGTH(val);
       if (s == 0)
 	len0 = len;
       else if (len != len0) {
-	errorcall(R_NilValue,"variable-sized results returned by probe %ld",p);
+	errorcall(R_NilValue,"variable-sized results returned by probe %ld",p+1);
       }
       if (k+len > nvals)
 	errorcall(R_NilValue,"probes return different number of values on different datasets");
